@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -120,25 +120,33 @@ tracker_dbus_request_add_hook       (TrackerDBusRequestFunc      new,
 void             tracker_dbus_request_remove_hook    (TrackerDBusRequestHandler  *handler);
 
 void             tracker_dbus_request_new            (gint                        request_id,
+                                                      DBusGMethodInvocation      *context,
                                                       const gchar                *format,
                                                       ...);
-void             tracker_dbus_request_success        (gint                        request_id);
+void             tracker_dbus_request_success        (gint                        request_id,
+                                                      DBusGMethodInvocation      *context);
 void             tracker_dbus_request_failed         (gint                        request_id,
+                                                      DBusGMethodInvocation      *context,
                                                       GError                    **error,
                                                       const gchar                *format,
                                                       ...);
 void             tracker_dbus_request_comment        (gint                        request_id,
+                                                      DBusGMethodInvocation      *context,
                                                       const gchar                *format,
                                                       ...);
 void             tracker_dbus_request_info           (gint                        request_id,
+                                                      DBusGMethodInvocation      *context,
                                                       const gchar                *format,
                                                       ...);
 void             tracker_dbus_request_debug          (gint                        request_id,
+                                                      DBusGMethodInvocation      *context,
                                                       const gchar                *format,
                                                       ...);
 void             tracker_dbus_request_block_hooks    (void);
 void             tracker_dbus_request_unblock_hooks  (void);
 
+void             tracker_dbus_enable_client_lookup   (gboolean                    enable);
+
 G_END_DECLS
 
 #endif /* __LIBTRACKER_COMMON_DBUS_H__ */
