@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Nokia
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,9 +42,6 @@ typedef gint (* TrackerDBCollationFunc) (gchar *str1,
                                          gint   len1,
                                          gchar *str2,
                                          gint   len2);
-typedef GValue (* TrackerDBFunc) (TrackerDBInterface *interface,
-                                  gint                argc,
-                                  GValue              argv[]);
 
 struct TrackerDBInterfaceSqlite {
 	GObject parent_instance;
@@ -58,15 +55,13 @@ GType               tracker_db_interface_sqlite_get_type               (void);
 
 TrackerDBInterface *tracker_db_interface_sqlite_new                    (const gchar              *filename);
 TrackerDBInterface *tracker_db_interface_sqlite_new_ro                 (const gchar              *filename);
-void                tracker_db_interface_sqlite_create_function        (TrackerDBInterface       *interface,
-                                                                        const gchar              *name,
-                                                                        TrackerDBFunc             func,
-                                                                        gint                      n_args);
 gboolean            tracker_db_interface_sqlite_set_collation_function (TrackerDBInterfaceSqlite *interface,
                                                                         const gchar              *name,
                                                                         TrackerDBCollationFunc    func);
 gint64              tracker_db_interface_sqlite_get_last_insert_id     (TrackerDBInterfaceSqlite *interface);
 void                tracker_db_interface_sqlite_enable_shared_cache    (void);
+void                tracker_db_interface_sqlite_fts_init               (TrackerDBInterfaceSqlite *interface,
+                                                                        gboolean                  create);
 
 G_END_DECLS
 
