@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -387,6 +387,11 @@ directory_root_info_free (DirectoryRootInfo *info)
 			 NULL);
 	g_node_destroy (info->tree);
 
+	g_queue_foreach (info->directory_processing_queue,
+			 (GFunc) directory_processing_data_free,
+			 NULL);
+	g_queue_free (info->directory_processing_queue);
+
 	g_slice_free (DirectoryRootInfo, info);
 }
 
