@@ -1,6 +1,5 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,11 +17,14 @@
  * Boston, MA  02110-1301, USA.
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 
+#include <dbus/dbus-glib-bindings.h>
+
 #include "tracker-dbus.h"
 #include "tracker-miner-dbus.h"
-#include <dbus/dbus-glib-bindings.h>
 
 typedef struct {
         DBusGConnection *connection;
@@ -215,8 +217,8 @@ dbus_data_create (TrackerMiner          *miner,
 }
 
 void
-tracker_miner_dbus_init (TrackerMiner          *miner,
-                         const DBusGObjectInfo *info)
+_tracker_miner_dbus_init (TrackerMiner          *miner,
+                          const DBusGObjectInfo *info)
 {
 	DBusData *data;
         gchar *name;
@@ -259,7 +261,7 @@ tracker_miner_dbus_init (TrackerMiner          *miner,
 }
 
 void
-tracker_miner_dbus_shutdown (TrackerMiner *miner)
+_tracker_miner_dbus_shutdown (TrackerMiner *miner)
 {
 	g_return_if_fail (TRACKER_IS_MINER (miner));
 
@@ -271,9 +273,9 @@ tracker_miner_dbus_shutdown (TrackerMiner *miner)
 }
 
 void
-tracker_miner_dbus_add_name_watch (TrackerMiner             *miner,
-                                   const gchar              *name,
-                                   TrackerMinerDBusNameFunc  func)
+_tracker_miner_dbus_add_name_watch (TrackerMiner             *miner,
+                                    const gchar              *name,
+                                    TrackerMinerDBusNameFunc  func)
 {
         DBusData *data;
 
