@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -37,7 +37,8 @@ typedef struct _TestInfo TestInfo;
 struct _TestInfo {
 	const gchar *test_name;
 	const gchar *data;
-	gboolean expect_error;
+	gboolean expect_query_error;
+	gboolean expect_update_error;
 };
 
 const TestInfo tests[] = {
@@ -55,8 +56,12 @@ const TestInfo tests[] = {
 	{ "algebra/filter-scope-1", "algebra/data-2", FALSE },
 	{ "algebra/var-scope-join-1", "algebra/var-scope-join-1", FALSE },
 	{ "anon/query", "anon/data", FALSE },
+	{ "ask/ask-1", "ask/data", FALSE },
 	{ "basic/base-prefix-3", "basic/data-1", FALSE },
 	{ "basic/predicate-variable", "basic/data-1", FALSE },
+	{ "basic/predicate-variable-2", "basic/data-1", FALSE },
+	{ "basic/predicate-variable-3", "basic/data-1", FALSE },
+	{ "basic/predicate-variable-4", "basic/data-1", FALSE },
 	{ "bnode-coreference/query", "bnode-coreference/data", FALSE },
 	{ "bound/bound1", "bound/data", FALSE },
 	{ "datetime/delete-1", "datetime/data-3", FALSE },
@@ -89,10 +94,12 @@ const TestInfo tests[] = {
 	{ "sort/query-sort-4", "sort/data-sort-4", FALSE },
 	{ "sort/query-sort-5", "sort/data-sort-4", FALSE },
 	{ "subqueries/subqueries-1", "subqueries/data-1", FALSE },
+	{ "subqueries/subqueries-union-1", "subqueries/data-1", FALSE },
 	/* Bracket error after WHERE */
-	{ "error/query-error-1", "error/query-error-1", TRUE },
+	{ "error/query-error-1", "error/query-error-1", TRUE, FALSE },
 	/* Unknown property */
-	{ "error/query-error-2", "error/query-error-2", TRUE },
+	{ "error/query-error-2", "error/query-error-2", TRUE, FALSE },
+	{ "error/update-error-query-1", "error/update-error-1", FALSE, TRUE },
 
 	{ "turtle/turtle-query-001", "turtle/turtle-data-001", FALSE },
 	{ "turtle/turtle-query-002", "turtle/turtle-data-002", FALSE },
@@ -131,7 +138,7 @@ test_sparql_query (gconstpointer test_data)
 	test_schemas[0] = data_prefix;
 	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
 	                           test_schemas,
-	                           NULL, FALSE);
+	                           NULL, FALSE, NULL, NULL, NULL);
 
 	/* data_path = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", NULL); */
 
@@ -155,7 +162,12 @@ test_sparql_query (gconstpointer test_data)
 		tracker_data_begin_db_transaction ();
 		tracker_data_update_sparql (data, &error);
 		tracker_data_commit_db_transaction ();
-		g_assert_no_error (error);
+		if (test_info->expect_update_error) {
+			g_assert (error != NULL);
+			g_clear_error (&error);
+		} else {
+			g_assert_no_error (error);
+		}
 
 		g_free (data);
 	}
@@ -175,7 +187,7 @@ test_sparql_query (gconstpointer test_data)
 
 	result_set = tracker_data_query_sparql (query, &error);
 
-	if (test_info->expect_error) {
+	if (test_info->expect_query_error) {
 		comparer = strstr_i;
 		g_assert (error != NULL);
 	} else {
@@ -226,7 +238,7 @@ test_sparql_query (gconstpointer test_data)
 		}
 
 		g_object_unref (result_set);
-	} else if (test_info->expect_error) {
+	} else if (test_info->expect_query_error) {
 		g_string_append (test_results, error->message);
 		g_clear_error (&error);
 	}
